==> atlas-json-model-1.34.2-sources.jar: io/atlasmap/json/v2/JsonFields.java <==

package io.atlasmap.json.v2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for JsonFields complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="JsonFields"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="JsonField" type="{http://atlasmap.io/json/v2}JsonField" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "JsonFields", propOrder = {
    "jsonField"
})
public class JsonFields implements Serializable
{

    private final static long serialVersionUID = 1L;
    @XmlElement(name = "JsonField")
    protected List<JsonField> jsonField;

    /**
     * Gets the value of the jsonField property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the jsonField property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getJsonField().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JsonField }
     * 
     * 
     */
    public List<JsonField> getJsonField() {
        if (jsonField == null) {
            jsonField = new ArrayList<JsonField>();
        }
        return this.jsonField;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final JsonFields that = ((JsonFields) object);
        {
            List<JsonField> leftJsonField;
            leftJsonField = (((this.jsonField!= null)&&(!this.jsonField.isEmpty()))?this.getJsonField():null);
            List<JsonField> rightJsonField;
            rightJsonField = (((that.jsonField!= null)&&(!that.jsonField.isEmpty()))?that.getJsonField():null);
            if ((this.jsonField!= null)&&(!this.jsonField.isEmpty())) {
                if ((that.jsonField!= null)&&(!that.jsonField.isEmpty())) {
                    if (!leftJsonField.equals(rightJsonField)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.jsonField!= null)&&(!that.jsonField.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<JsonField> theJsonField;
            theJsonField = (((this.jsonField!= null)&&(!this.jsonField.isEmpty()))?this.getJsonField():null);
            if ((this.jsonField!= null)&&(!this.jsonField.isEmpty())) {
                currentHashCode += theJsonField.hashCode();
            }
        }
        return currentHashCode;
    }

}

==> atlas-json-model-2.5.2-sources.jar: io/atlasmap/json/v2/JsonFields.java <==
/*
 * Copyright (C) 2017 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.atlasmap.json.v2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class JsonFields implements Serializable {

    private static final long serialVersionUID = 1L;

    protected List<JsonField> jsonField;

    /**
     * Gets the value of the jsonField property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the jsonField property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getJsonField().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JsonField }
     * @return A list of {@link JsonField}
     * 
     */
    public List<JsonField> getJsonField() {
        if (jsonField == null) {
            jsonField = new ArrayList<JsonField>();
        }
        return this.jsonField;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final JsonFields that = ((JsonFields) object);
        {
            List<JsonField> leftJsonField;
            leftJsonField = (((this.jsonField!= null)&&(!this.jsonField.isEmpty()))?this.getJsonField():null);
            List<JsonField> rightJsonField;
            rightJsonField = (((that.jsonField!= null)&&(!that.jsonField.isEmpty()))?that.getJsonField():null);
            if ((this.jsonField!= null)&&(!this.jsonField.isEmpty())) {
                if ((that.jsonField!= null)&&(!that.jsonField.isEmpty())) {
                    if (!leftJsonField.equals(rightJsonField)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.jsonField!= null)&&(!that.jsonField.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<JsonField> theJsonField;
            theJsonField = (((this.jsonField!= null)&&(!this.jsonField.isEmpty()))?this.getJsonField():null);
            if ((this.jsonField!= null)&&(!this.jsonField.isEmpty())) {
                currentHashCode += theJsonField.hashCode();
            }
        }
        return currentHashCode;
    }

}
